==> dde-shell_1.99.36.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Moda Kipi</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Verimli Kip</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Klasik Kip</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Ortalanmış Kip</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Konum</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Kip</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Üst</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Durum</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Sürekli Göster</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Sürekli Gizle</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Akıllı Gizle</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Rıhtım Ayarları</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.3.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Gösterge Stili</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Moda Kipi</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Verimli Kip</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Klasik Kip</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Ortalanmış Kip</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Konum</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Kip</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Üst</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Durum</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Sürekli Göster</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Sürekli Gizle</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Akıllı Gizle</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Rıhtım Ayarları</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation>Özgür Ayarlamayı Devre Dışı Bırak</translation>
    </message>
</context>
</TS>
